@@ -22,7 +22,7 @@ import (
 
 	"github.com/onsi/gomega"
 	clusterv1alpha1 "github.com/open-cluster-management/api/cluster/v1alpha1"
-	gitopsclusterV1alpha1 "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/apis/apps/v1alpha1"
+	gitopsclusterV1alpha1 "github.com/stolostron/multicloud-operators-placementrule/pkg/apis/apps/v1alpha1"
 	corev1 "k8s.io/api/core/v1"
 	rbacv1 "k8s.io/api/rbac/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
